@@ -25,7 +25,7 @@ GSC.getMessage = function(key) {
 };
 
 define('gs-chrome', ['jquery'], function($) {
-    "use strict";
+	"use strict";
 
 	window.SweetTooth = function() {
 		var apiObject			= {
@@ -65,21 +65,52 @@ define('gs-chrome', ['jquery'], function($) {
 				return sendResolveExtensionMessage("uninstallExtension", "success", {uuid: uuid});
 			},
 
-			initialize:		function(done, fail, always) {
+			initialize:		function() {
 				var ready = $.Deferred();
-				if(done)
+
+				if(SweetTooth.shellVersion !== '-1')
 				{
-					ready.done(done);
+					ready.resolve();
 				}
-				if(fail)
+				else
 				{
-					ready.fail(fail);
+					require(['jquery', 'messages'], function($, messages) {
+						var connectingInfo = GSC.getMessage('connecting_host_app');
+						messages.addInfo(connectingInfo);
+
+						ready.done(function(response) {
+							apiObject.shellVersion			= response.shellVersion;
+							apiObject.versionValidationEnabled	= response.versionValidationEnabled;
+
+							if(!response.connectorVersion ||
+									(
+										response.connectorVersion != 7.1 &&
+										response.connectorVersion != GS_CHROME_VERSION
+									)
+							)
+							{
+								if(!response.connectorVersion)
+									response.connectorVersion = GSC.getMessage('older_connector');
+								else
+									response.connectorVersion = GSC.getMessage('version', response.connectorVersion);
+
+								messages.addWarning(GSC.getMessage('warning_versions_mismatch', GSC.getMessage('version', GS_CHROME_VERSION), response.connectorVersion));
+							}
+
+							$('#message_container')
+								.find('.message:contains("' + connectingInfo + '")')
+								.remove();
+						});
+
+						ready.fail(function(message) {
+							messages.addWarning(message ? message : GSC.getMessage('no_host_connector'));
+						});
+
+						sendResolveExtensionMessage("initialize", "properties", null, ready);
+					});
 				}
-				if(always)
-				{
-					ready.always(always);
-				}
-				sendResolveExtensionMessage("initialize", "properties", null, ready);
+
+				return ready;
 			}
 		};
 
@@ -154,135 +185,13 @@ define('gs-chrome', ['jquery'], function($) {
 	} ();
 });
 
-define('versions/common/common', ['jquery', 'dbus!API'], function($, API) {
-    "use strict";
-
-     function _makeRawPromise(result) {
-        // Check if result is promise already
-        if(isPromise(result))
-            return result;
-
-        return (new $.Deferred()).resolve(result);
-    }
-
-    function _makePromise(result) {
-        // Check if result is promise already
-        if(isPromise(result))
-            return result;
-
-        return _makeRawPromise(JSON.parse(result));
-    }
-
-    function isPromise(value) {
-        return value && value.promise;
-    }
-
-    return {
-        _makePromise: _makePromise,
-
-        ListExtensions: function() {
-            return _makePromise(API.listExtensions());
-        },
-
-        GetExtensionInfo: function(uuid) {
-            return _makePromise(API.getExtensionInfo(uuid));
-        },
-
-        GetErrors: function(uuid) {
-            return _makePromise(API.getExtensionErrors(uuid));
-        },
-
-        LaunchExtensionPrefs: function(uuid) {
-            return API.launchExtensionPrefs(uuid);
-        },
-
-        LaunchExtensionPrefsDummy: function(uuid) { },
-
-        EnableExtension: function(uuid) {
-            API.setExtensionEnabled(uuid, true);
-        },
-
-        DisableExtension: function(uuid) {
-            API.setExtensionEnabled(uuid, false);
-        },
-
-        InstallExtensionOne: function(uuid) {
-            var result = API.installExtension(uuid);
-
-	    if(isPromise(result))
-		    return result;
-
-            return _makeRawPromise('succeeded');
-        },
-
-        InstallExtensionTwo: function(uuid) {
-            var result = API.installExtension(uuid, "");
-
-	    if(isPromise(result))
-		    return result;
-
-            return _makeRawPromise('succeeded');
-        },
-
-        InstallExtensionAsync: function(uuid) {
-            var d = new $.Deferred();
-            var result = API.installExtension(uuid, d.done.bind(d), d.fail.bind(d));
-
-	    if(isPromise(result))
-		    return result;
-
-            return d;
-        },
-
-        UninstallExtension: function(uuid) {
-            return _makePromise(API.uninstallExtension(uuid));
-        },
-
-        API_onchange: function(proxy) {
-            return function(uuid, newState, error) {
-                if (proxy.extensionStateChangedHandler !== null)
-                    proxy.extensionStateChangedHandler(uuid, newState, error);
-            };
-        },
-
-        API_onshellrestart: function(proxy) {
-            return function() {
-                if (proxy.shellRestartHandler !== null)
-                    proxy.shellRestartHandler();
-            };
-        }
-    };
-});
-
 gs_chrome_initialized = true;
 
 requirejs.config({
 	waitSeconds: 15 // It's fails sometimes with default 7 secs
 });
 require(['jquery', 'messages', 'gs-chrome'], function($, messages){
-	var connectingInfo = GSC.getMessage('connecting_host_app');
-	messages.addInfo(connectingInfo);
-
-	SweetTooth.initialize(function(response) {
-		SweetTooth.shellVersion			= response.shellVersion;
-		SweetTooth.versionValidationEnabled	= response.versionValidationEnabled;
-
-		if(!response.connectorVersion || response.connectorVersion != GS_CHROME_VERSION)
-		{
-			if(!response.connectorVersion)
-				response.connectorVersion = GSC.getMessage('older_connector');
-			else
-				response.connectorVersion = GSC.getMessage('version', response.connectorVersion);
-
-			messages.addWarning(GSC.getMessage('warning_versions_mismatch', GSC.getMessage('version', GS_CHROME_VERSION), response.connectorVersion));
-		}
-
-		$('#message_container')
-			.find('.message:contains("' + connectingInfo + '")')
-			.remove();
-	}, function(message) {
-		messages.addWarning(message ? message : GSC.getMessage('no_host_connector'));
-	}, function() {
+	SweetTooth.initialize().always(function() {
 		// Start extensions.gnome.org main script
 		require(['main'], function(){});
 	});
